SOCKET BRANCH:
[lcr.git] / mISDN.h
diff --git a/mISDN.h b/mISDN.h
index 030c5fc..de33e16 100644 (file)
--- a/mISDN.h
+++ b/mISDN.h
@@ -1,6 +1,6 @@
 /*****************************************************************************\
 **                                                                           **
-** PBX4Linux                                                                 **
+** Linux Call Router                                                         **
 **                                                                           **
 **---------------------------------------------------------------------------**
 ** Copyright: Andreas Eversberg                                              **
@@ -9,20 +9,6 @@
 **                                                                           **
 \*****************************************************************************/ 
 
-enum {
-       B_STATE_IDLE,
-       B_STATE_ACTIVATING,
-       B_STATE_ACTIVE,
-       B_STATE_DEACTIVATING,
-};
-
-enum {
-       B_EVENT_ACTIVATE,
-       B_EVENT_ACTIVATED,
-       B_EVENT_DEACTIVATE,
-       B_EVENT_DEACTIVATED,
-};
-
 #define FROMUP_BUFFER_SIZE 1024
 #define FROMUP_BUFFER_MASK 1023
 
@@ -31,35 +17,49 @@ extern int mISDNdevice;
 
 /* mISDN port structure list */
 struct mISDNport {
+#ifdef SOCKET_MISDN
+       struct mlayer3 *ml3;
+#else
        net_stack_t nst; /* MUST be the first entry, so &nst equals &mISDNlist */
        manager_t mgr;
+       int upper_id; /* id to transfer data down */
+       int lower_id; /* id to transfer data up */
+       int d_stid;
+       msg_queue_t downqueue;          /* l4->l3 */
+#endif
        struct mISDNport *next;
+       char name[64]; /* name of port, if available */
        struct interface_port *ifport; /* link to interface_port */
 //     int iftype; /* IF_* */
 //     int multilink; /* if set, this port will not support callwaiting */
-       int portnum; /* port number */
+       int portnum; /* port number 1..n */
        int ptp; /* if ptp is set, we keep track of l2link */
        int l1link; /* if l1 is available (only works with nt-mode) */
        int l2link; /* if l2 is available (at PTP we take this serious) */
-//     time_t l1timeout; /* timout when establishing link */
+       int l2hold; /* set, if layer 2 must be hold/checked */
        time_t l2establish; /* time until establishing after link failure */
        int use; /* counts the number of port that uses this port */
        int ntmode; /* is TRUE if port is nt mode */
        int pri; /* is TRUE if port is a primary rate interface */
        int tones; /* TRUE if tones are sent outside connect state */
        int earlyb; /* TRUE if tones are received outside connect state */
-       int upper_id; /* id to transfer data down */
-       int lower_id; /* id to transfer data up */
-       int d_stid;
        int b_num; /* number of bchannels */
        int b_reserved; /* number of bchannels reserved or in use */
-       class PmISDN *b_port[128]; /* maximum number of ports shall be 128 due to S0 / E1 / special E1 */
+       class PmISDN *b_port[128]; /* bchannel assigned to port object */
+#ifdef SOCKET_MISDN
+       struct mqueue upqueue;
+       int b_socket[128];
+#else
+       int procids[256]; /* keep track of free ids */
        int b_stid[128];
-       int b_addr[128];
-       int b_state[128]; /* state 0 = IDLE */
-       int procids[128]; /* keep track of free ids */
+       unsigned long b_addr[128];
+#endif
+       int b_state[128]; /* statemachine, 0 = IDLE */
+       double b_timer[128]; /* timer for state machine */
+       unsigned long b_remote_id[128]; /* the socket currently exported */
+       unsigned long b_remote_ref[128]; /* the ref currently exported */
        int locally; /* local causes are sent as local causes not remote */
-       msg_queue_t downqueue;          /* l4->l3 */
+       int los, ais, rdi, slip_rx, slip_tx;
 };
 extern mISDNport *mISDNport_first;
 
@@ -79,22 +79,30 @@ calls with no bchannel (call waiting, call on hold).
 
 
 /* mISDN none-object functions */
+int mISDN_initialize(void);
+void mISDN_deinitialize(void);
 void mISDN_port_info(void);
-struct mISDNport *mISDNport_open(int port, int ptp, int ptmp, struct interface *interface);
+struct mISDNport *mISDNport_open(int port, int ptp, int force_nt, int l2hold, struct interface *interface);
 void mISDNport_close_all(void);
 void mISDNport_close(struct mISDNport *mISDNport);
 void mISDN_port_reorder(void);
 int mISDN_handler(void);
+#ifdef SOCKET_MISDN
+void enc_ie_cause_standalone(struct l3_msg *l3m, int location, int cause);
+int stack2manager(struct mISDNport *mISDNport, unsigned int cmd, unsigned int pid, struct l3_msg *l3m);
+#else
 void enc_ie_cause_standalone(unsigned char **ntmode, msg_t *msg, int location, int cause);
-void ph_control(struct mISDNport *mISDNport, class PmISDN *isdnport, unsigned long b_addr, int c1, int c2, char *trace_name, int trace_value);
-void ph_control_block(struct mISDNport *mISDNport, unsigned long b_addr, int c1, void *c2, int c2_len, char *trace_name, int trace_value);
-msg_t *create_l2msg(int prim, int dinfo, int size);
-void setup_queue(struct mISDNport *mISDNport, int link);
-int stack2manager_nt(void *dat, void *arg);
 int stack2manager_te(struct mISDNport *mISDNport, msg_t *msg);
+int stack2manager_nt(void *dat, void *arg);
+void setup_queue(struct mISDNport *mISDNport, int link);
+msg_t *create_l2msg(int prim, int dinfo, int size);
+#endif
+void ph_control(struct mISDNport *mISDNport, class PmISDN *isdnport, unsigned long handle, unsigned long c1, unsigned long c2, char *trace_name, int trace_value);
+void ph_control_block(struct mISDNport *mISDNport, unsigned long handle, unsigned long c1, void *c2, int c2_len, char *trace_name, int trace_value);
 void chan_trace_header(struct mISDNport *mISDNport, class PmISDN *port, char *msgtext, int direction);
 void l1l2l3_trace_header(struct mISDNport *mISDNport, class PmISDN *port, unsigned long prim, int direction);
 void bchannel_event(struct mISDNport *mISDNport, int i, int event);
+void message_bchannel_from_join(class JoinRemote *joinremote, int type, unsigned long handle);
 
 
 /* mISDN port classes */
@@ -103,7 +111,11 @@ class PmISDN : public Port
        public:
        PmISDN(int type, struct mISDNport *mISDNport, char *portname, struct port_settings *settings, int channel, int exclusive);
        ~PmISDN();
+#ifdef SOCKET_MISDN
+       void bchannel_receive(struct mISDNhead *hh, unsigned char *data, int len);
+#else
        void bchannel_receive(iframe_t *frm);
+#endif
        int handler(void);
        void transmit(unsigned char *buffer, int length);
        int message_epoint(unsigned long epoint_id, int message, union parameter *param);
@@ -111,14 +123,15 @@ class PmISDN : public Port
        void message_crypt(unsigned long epoint_id, int message_id, union parameter *param);
        struct mISDNport *p_m_mISDNport;        /* pointer to port */
        int p_m_delay;                          /* use delay instead of dejitter */
-       int p_m_txvol, p_m_rxvol;               /* volume shift (0 = no change) */
+       int p_m_tx_gain, p_m_rx_gain;           /* volume shift (0 = no change) */
+       char p_m_pipeline[256];                 /* filter pipeline */
        int p_m_echo, p_m_conf;                 /* remote echo, conference number */
        int p_m_tone;                           /* current kernel space tone */
        int p_m_rxoff;                          /* rx from driver is disabled */
 //     int p_m_nodata;                         /* all parties within a conf are isdn ports, so pure bridging is possible */
        int p_m_txdata;                         /* get what we transmit */
        int p_m_dtmf;                           /* dtmf decoding is enabled */
-       int p_m_calldata;                       /* the call requires data due to no briging capability */
+       int p_m_joindata;                       /* the call requires data due to no briging capability */
 
        int p_m_load;                           /* current data in dsp tx buffer */
        unsigned long p_m_last_tv_sec;          /* time stamp of last handler call, (to sync audio data */
@@ -156,6 +169,8 @@ class PmISDN : public Port
        int p_m_hold;                           /* if port is on hold */
        unsigned long p_m_timeout;              /* timeout of timers */
        time_t p_m_timer;                       /* start of timer */
+       unsigned char p_m_remote_ref;           /* join to export bchannel to */
+       unsigned char p_m_remote_id;            /* sock to export bchannel to */
 
        int seize_bchannel(int channel, int exclusive); /* requests / reserves / links bchannels, but does not open it! */
        void drop_bchannel(void);